# -*- coding: utf-8 -*-
"""Package metadata/info"""

__title__ = 'h5'
__version__ = '0.5.0'
__license__ = 'MIT'
__description__ = 'H5py utils'
